==> falak-1.3.2.tgz: package/framework/production/compile-vendors.js <==
const babel = require("@babel/core");
const { fs } = require('./../bootstrap/modules');

const { sha1 } = require('./../helpers/manager');

function compile(hash, appDistPath) {
    return new Promise(resolve => {
        let vendorContent = '';

        echo(cli.magenta('Bundling vendors...'));
        let result = { code: '' };

        let paths = resources.jsVendor;

        for (let vendorFile of paths) {
            // vendorContent += fs.get(ROOT + '/' + vendorFile.ltrim('/')) + "\r\n";
            let c = fs.get(vendorFile) + ";\n";
            
            vendorContent += c;

            // if (vendorFile.endsWith('.min.js')) {
            //     vendorContent += c;
            //     continue;
            // }

            // echo(vendorFile)
            // let compiled = babel.transformSync(c, {
            //     envName: 'production',
            //     "comments": false,
            //     presets: [
            //         '@babel/preset-env',
            //         // ['minify', {
            //         //     builtIns: false,
            //         // }]
            //     ],
            // });

            // vendorContent += compiled.code + "\n";

            // echo(compiled.code.length)
        }

        // let result = {
        //     code: vendorContent
        // };

        /// to make sure vendors files are remained cached of no vendor updates happen

        vendorContent = babel.transformSync(vendorContent, {
            envName: 'production',
            "comments": false,
            // plugins: [
            //     "@babel/plugin-proposal-class-properties"
            // ],
            presets: [
                // '@babel/preset-env',
                ['minify', {
                    builtIns: false,
                }]]
        }).code;

        // // generators
        // vendorContent = fs.get(NODE_MODULES_DIR + '/regenerator-runtime/runtime.js') + ';' + vendorContent;

        hash = sha1(vendorContent);

        global.vendorHash = hash;

        fs.put(appDistPath + `/js/vendor-${hash}.min.js`, vendorContent);
        // fs.put(appDistPath + `/js/vendor-${hash}.min.js`, vendorContent);
        resolve();
    });
}

module.exports = (hash, appDistPath) => compile(hash, appDistPath);

==> falak-1.3.9.tgz: package/framework/production/compile-vendors.js <==
const babel = require("@babel/core");
const { fs } = require('./../bootstrap/modules');

const { sha1 } = require('./../helpers/manager');

function compile(hash, appDistPath) {
    return new Promise(resolve => {
        let vendorContent = '';

        echo(cli.magenta('Bundling vendors...'));
        let result = { code: '' };

        let paths = resources.jsVendor;

        for (let vendorFile of paths) {
            // vendorContent += fs.get(ROOT + '/' + vendorFile.ltrim('/')) + "\r\n";
            let c = fs.get(vendorFile) + ";\n";
            
            vendorContent += c;

            // if (vendorFile.endsWith('.min.js')) {
            //     vendorContent += c;
            //     continue;
            // }

            // echo(vendorFile)
            // let compiled = babel.transformSync(c, {
            //     envName: 'production',
            //     "comments": false,
            //     presets: [
            //         '@babel/preset-env',
            //         // ['minify', {
            //         //     builtIns: false,
            //         // }]
            //     ],
            // });

            // vendorContent += compiled.code + "\n";

            // echo(compiled.code.length)
        }

        // let result = {
        //     code: vendorContent
        // };

        /// to make sure vendors files are remained cached of no vendor updates happen

        // vendorContent = babel.transformSync(vendorContent, {
        //     envName: 'production',
        //     "comments": false,
        //     // plugins: [
        //     //     "@babel/plugin-proposal-class-properties"
        //     // ],
        //     presets: [
        //         // '@babel/preset-env',
        //         ['minify', {
        //             builtIns: false,
        //         }]]
        // }).code;

        // // generators
        // vendorContent = fs.get(NODE_MODULES_DIR + '/regenerator-runtime/runtime.js') + ';' + vendorContent;

        hash = sha1(vendorContent);

        global.vendorHash = hash;

        fs.put(appDistPath + `/js/vendor-${hash}.min.js`, vendorContent);
        // fs.put(appDistPath + `/js/vendor-${hash}.min.js`, vendorContent);
        resolve();
    });
}

module.exports = (hash, appDistPath) => compile(hash, appDistPath);
